BrowserTestFailurePolicy

Enum BrowserTestFailurePolicy 

pub enum BrowserTestFailurePolicy {
    FailFast,
    RunAll,
}
How crate::BrowserTestRunner handles failed browser tests.

Variants



FailFast

Stop after the first failed test.

When tests are running in parallel, the runner stops starting additional tests and waits for already-started sessions to finish before reporting failures from those sessions.



RunAll

Run every test and return all failures as child reports on one aggregate report.