BrowserTests

Struct BrowserTests 

pub struct BrowserTests<Context = (), TestError = Dynamic>
where Context: Sync + ?Sized, TestError: ?Sized,
{ /* private fields */ }
A collection of browser tests for crate::BrowserTestRunner.

This type erases each concrete test into the boxed trait object used by the runner while keeping call sites concise.

Examples


#[async_trait]
impl BrowserTest for OpensHomePage {
    fn name(&self) -> Cow<'_, str> { "opens home page".into() }
    async fn run(&self, _driver: &WebDriver, _context: &()) -> Result<(), Report> { Ok(()) }
}

struct SearchWorks;
#[async_trait]
impl BrowserTest for SearchWorks {
    fn name(&self) -> Cow<'_, str> { "search works".into() }
    async fn run(&self, _driver: &WebDriver, _context: &()) -> Result<(), Report> { Ok(()) }
}

let tests = BrowserTests::new()
    .with(OpensHomePage)
    .with(SearchWorks);

Implementations

Source

impl<Context, TestError> BrowserTests<Context, TestError>
where Context: Sync + ?Sized, TestError: ?Sized,

pub const fn new() -> Self

Creates an empty browser test collection.

pub fn with<T>(self, test: T) -> Self
where T: BrowserTest<Context, TestError> + 'static,

Adds a test and returns the collection for chaining.

pub fn push<T>(&mut self, test: T) -> &mut Self
where T: BrowserTest<Context, TestError> + 'static,

Adds a test to the collection.

pub fn is_empty(&self) -> bool

Returns true if the collection contains no tests.