BrowserTestError

Enum BrowserTestError 

pub enum BrowserTestError {
    StartWebdriver,
    RunTest {
        test_name: String,
    },
    Panic {
        test_name: String,
        message: String,
    },
    RunTests {
        failed_tests: usize,
    },
    TerminateWebdriver,
    FlushPausePrompt,
    ReadPauseResponse,
}
Error contexts reported by browser-test runner operations.

Variants



StartWebdriver

Chromedriver could not be started.



RunTest

A browser test failed while running in its WebDriver session.

Fields

test_name: String

The test name reported by crate::BrowserTest::name.



Panic

A browser test panicked while running in its WebDriver session.

Fields

test_name: String

The test name reported by crate::BrowserTest::name.

message: String

A string representation of the panic payload.



RunTests

Multiple browser tests failed or panicked and were collected into one report.

Fields

failed_tests: usize

Number of failed or panicked tests collected as child reports.



TerminateWebdriver

Chromedriver could not be terminated cleanly.



FlushPausePrompt

The pause prompt could not be flushed to stdout.



ReadPauseResponse

The pause response could not be read from stdin.