pub struct ElementQueryWaitConfig { /* private fields */ }Expand description
Wait configuration used by thirtyfour element queries and element waits.
Implementations
Sourceimpl ElementQueryWaitConfig
impl ElementQueryWaitConfig
Sourcepub const fn new(timeout: Duration, interval: Duration) -> Self
pub const fn new(timeout: Duration, interval: Duration) -> Self
Create a new element query wait configuration without validation.
Use Self::try_new for values from user input or environment configuration. A zero
interval is accepted here for const construction, but can cause immediate retry loops in the
underlying WebDriver element poller.
Sourcepub fn try_new(
timeout: Duration,
interval: Duration,
) -> Result<Self, ElementQueryWaitConfigError>
pub fn try_new( timeout: Duration, interval: Duration, ) -> Result<Self, ElementQueryWaitConfigError>
Create a new element query wait configuration.
Errors
Returns ElementQueryWaitConfigError::ZeroInterval if interval is
Duration::ZERO.