pub struct PauseConfig { /* private fields */ }Expand description
Configuration for the manual pause before browser tests execute.
Implementations
Sourceimpl PauseConfig
impl PauseConfig
Sourcepub fn from_env() -> Self
pub fn from_env() -> Self
Build a pause config from BROWSER_TEST_PAUSE.
The variable is considered enabled unless it is unset, empty, 0, false, no, or off.
Sourcepub fn from_env_var(env_var: impl AsRef<str>) -> Self
pub fn from_env_var(env_var: impl AsRef<str>) -> Self
Build a pause config from an environment variable.
The variable is considered enabled unless it is unset, empty, 0, false, no, or off.
Sourcepub fn with_message(self, message: impl Into<Cow<'static, str>>) -> Self
pub fn with_message(self, message: impl Into<Cow<'static, str>>) -> Self
Set the message printed before the prompt.
Sourcepub fn with_prompt(self, prompt: impl Into<Cow<'static, str>>) -> Self
pub fn with_prompt(self, prompt: impl Into<Cow<'static, str>>) -> Self
Set the interactive prompt.
Sourcepub const fn is_enabled(&self) -> bool
pub const fn is_enabled(&self) -> bool
Whether the pause is enabled.